<?php

declare(strict_types=1);

namespace Silex\Controller;

use Silex\DI\DI;
use Silex\Http\HttpResponse;
use Silex\Model\User;

class SecurityController
{
    public function login(DI $di): HttpResponse
    {
        $fail = false;
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $success = $di->getSecurity()->initLogin($_POST['login'], $_POST['password']);
            if ($success) {
                HttpResponse::redirect($di->getRouter()->url(''));
            }
            $fail = !$success;
        }
        return HttpResponse::found('login', ['fail' => $fail]);
    }

    public function register(DI $di): HttpResponse
    {
        $fail = false;
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $user = $di->getSecurity()->register(User::fromRawPassword($_POST['login'], $_POST['password']));
            if ($user !== null) {
                HttpResponse::redirect($di->getRouter()->url(''));
            }
            $fail = $user === null;
        }
        return HttpResponse::found('register', ['fail' => $fail]);
    }

    public function logout(DI $di): void
    {
        $di->getSecurity()->logout();
        HttpResponse::redirect($di->getRouter()->url(''));
    }
}
